@@ -14,37 +14,42 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import logging
 import sys
 
-import constants
 import yaml
 
+from bandit.core import constants
+from bandit.core import utils
+
+
+logger = logging.getLogger(__name__)
+
 
 class BanditConfig():
-
-    _config = dict()
-    _logger = None
-    _settings = dict()
-
-    def __init__(self, logger, config_file):
+    def __init__(self, config_file):
         '''Attempt to initialize a config dictionary from a yaml file.
 
         Error out if loading the yaml file fails for any reason.
-        :param logger: Logger to be used in the case of errors
         :param config_file: The Bandit yaml config file
-        :return: -
+
+        :raises bandit.utils.ConfigFileUnopenable: If the config file cannot be
+            opened.
+        :raises bandit.utils.ConfigFileInvalidYaml: If the config file cannot
+            be parsed.
+
         '''
 
-        self._logger = logger
-
+        self.config_file = config_file
         try:
             f = open(config_file, 'r')
         except IOError:
-            logger.error("could not open config file: %s" % config_file)
-            sys.exit(2)
-        else:
-            # yaml parser does its own exception handling
+            raise utils.ConfigFileUnopenable(config_file)
+
+        try:
             self._config = yaml.safe_load(f)
+        except yaml.YAMLError:
+            raise utils.ConfigFileInvalidYaml(config_file)
 
         self._init_settings()
 
@@ -60,15 +65,8 @@ class BanditConfig():
         option_levels = option_string.split('.')
         cur_item = self._config
         for level in option_levels:
-            if level in cur_item:
-                try:
-                    cur_item = cur_item[level]
-                except Exception:
-                    self._logger.error(
-                        "error while accessing config property: %s" %
-                        option_string
-                    )
-                    return None
+            if cur_item and (level in cur_item):
+                cur_item = cur_item[level]
             else:
                 return None
 
@@ -97,9 +95,9 @@ class BanditConfig():
         possible).
         :return: -
         '''
+        self._settings = {}
         self._init_progress_increment()
         self._init_output_colors()
-        self._init_plugins_dir()
         self._init_plugin_name_pattern()
 
     def _init_progress_increment(self):
@@ -144,13 +142,6 @@ class BanditConfig():
             settings_string = 'color_' + color
             self._settings[settings_string] = color_settings[color]
 
-    def _init_plugins_dir(self):
-        '''Sets settings['plugins_dir'] from default or config file.'''
-        plugins_dir = constants.plugins_dir
-        if self.get_option('plugins_dir'):
-            plugins_dir = self.get_option('plugins_dir')
-        self._settings['plugins_dir'] = plugins_dir
-
     def _init_plugin_name_pattern(self):
         '''Sets settings['plugin_name_pattern'] from default or config file.'''
         plugin_name_pattern = constants.plugin_name_pattern
