@@ -299,7 +299,7 @@ class FunctionalTests(testtools.TestCase):
         '''Test for `subprocess.Popen` with `shell=True`.'''
         expect = {
             'SEVERITY': {'HIGH': 3, 'MEDIUM': 2, 'LOW': 12},
-            'CONFIDENCE': {'HIGH': 17}
+            'CONFIDENCE': {'HIGH': 16, 'LOW': 1}
         }
         self.check_example('subprocess_shell.py', expect)
 
